@@ -3,6 +3,8 @@ package MooseX::Scaffold::Class;
 use strict;
 use warnings;
 
+use Carp::Clan qr/^MooseX::Scaffold/;
+
 use overload
     "" => \&name,
     fallback => 1,
@@ -38,6 +40,10 @@ for my $method (qw/ extends has before after around super override augment /) {
 sub class_has {
     my $self = shift;
     # TODO Check to see if the proper role has been applied first
+
+    unless ($self->meta->can('add_class_attribute')) {
+        croak "Can't add class attribute: You need to 'use MooseX::ClassAttribute' in ", $self->name;
+    }
     return MooseX::ClassAttribute::class_has($self->package, @_);
 }
 
